@@ -8,12 +8,14 @@
 }
 
 .onAttach <- function(libname, pkgname) {
-    packageStartupMessage(
-        paste("\nWelcome to Bioconductor\n",
-                "Vignettes contain introductory material. To view, type",
-                "'browseVignettes()'. To cite Bioconductor, see",
-                "'citation(\"Biobase\")' and for packages 'citation(\"pkgname\")'.\n", sep="\n  "))
-   addVigs2WinMenu("Biobase") 
+    msg0 <- "Vignettes contain introductory material; view with
+             'browseVignettes()'. To cite Bioconductor, see
+             'citation(\"Biobase\")', and for packages
+             'citation(\"pkgname\")'."
+    msg <- strwrap(paste(msg0, collapse=""), exdent=4, indent=4)
+    packageStartupMessage(paste(c("Welcome to Bioconductor\n", msg),
+                                collapse="\n"), "\n")
+    addVigs2WinMenu("Biobase") 
 }
 
 .onUnload <- function( libpath ) {
